@@ -15,13 +15,17 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: wordlist.cpp 708922 2007-09-06 02:06:26Z amth $
+// $Id: wordlist.cpp 1178876 2010-09-24 07:47:31Z mlaurent $
 
 #include "wordlist.h"
 
 #include <QtCore/QRegExp>
 #include <QtCore/QDir>
 #include <QtCore/QTextStream>
+#include <QtXml/QXmlParseException>
+#include <QtXml/QXmlAttributes>
+#include <QtXml/QXmlInputSource>
+#include <QtXml/QXmlSimpleReader>
 
 #include <kstandarddirs.h>
 #include <kprogressdialog.h>
@@ -50,7 +54,7 @@ bool XMLParser::fatalError (const QXmlParseException &) {
 }
 
 QString XMLParser::errorString() const {
-   return "";
+   return QLatin1String( "" );
 }
 
 bool XMLParser::startDocument() {
@@ -127,7 +131,7 @@ bool saveWordList (WordMap map, QString filename) {
 
    stream << "WPDictFile\n";
    WordMap::ConstIterator it;
-   for (it = map.begin(); it != map.end(); ++it)
+   for (it = map.constBegin(); it != map.constEnd(); ++it)
       stream << it.key() << "\t" << it.value() << "\t2\n";
    file.close();
    return true;
@@ -136,11 +140,11 @@ bool saveWordList (WordMap map, QString filename) {
 /***************************************************************************/
 
 void addWords (WordMap &map, QString line) {
-   QStringList words = line.split( QRegExp("\\W"));
+   const QStringList words = line.split( QRegExp(QLatin1String( "\\W" )));
 
    QStringList::ConstIterator it;
-   for (it = words.begin(); it != words.end(); ++it) {
-      if (!(*it).contains(QRegExp("\\d|_"))) {
+   for (it = words.constBegin(); it != words.constEnd(); ++it) {
+      if (!(*it).contains(QRegExp(QLatin1String( "\\d|_" )))) {
          QString key = (*it).toLower();
          if (map.contains(key))
             map[key] += 1;
@@ -152,7 +156,7 @@ void addWords (WordMap &map, QString line) {
 
 void addWords (WordMap &map, WordMap add) {
    WordList::WordMap::ConstIterator it;
-   for (it = add.begin(); it != add.end(); ++it)
+   for (it = add.constBegin(); it != add.constEnd(); ++it)
       if (map.contains(it.key()))
          map[it.key()] += it.value();
       else
@@ -164,7 +168,7 @@ void addWordsFromFile (WordMap &map, QString filename, QTextStream::Encoding enc
    QXmlInputSource source (&xmlfile);
    XMLParser parser;
    QXmlSimpleReader reader;
-   reader.setFeature ("http://trolltech.com/xml/features/report-start-end-entity", true);
+   reader.setFeature (QLatin1String( "http://trolltech.com/xml/features/report-start-end-entity" ), true);
    reader.setContentHandler (&parser);
 
    WordMap words;
@@ -178,12 +182,12 @@ void addWordsFromFile (WordMap &map, QString filename, QTextStream::Encoding enc
 
          if (!stream.atEnd()) {
             QString s = stream.readLine();
-            if (s == "WPDictFile") { // Contains the file a weighted word list?
+            if (s == QLatin1String( "WPDictFile" )) { // Contains the file a weighted word list?
                // We can assume that weighted word lists are always UTF8 coded.
                while (!stream.atEnd()) {
                   QString s = stream.readLine();
                   if (!(s.isNull() || s.isEmpty())) {
-                     QStringList list = s.split( "\t");
+                     QStringList list = s.split( QLatin1Char( '\t' ));
                      bool ok;
                      int weight = list[1].toInt(&ok);
                      if (ok && (weight > 0)) {
@@ -223,7 +227,7 @@ WordMap parseFiles (QStringList files, QTextStream::Encoding encoding, QTextCode
 
    WordMap map;
    QStringList::ConstIterator it;
-   for (progress = 1, it = files.begin(); it != files.end(); ++progress, ++it) {
+   for (progress = 1, it = files.constBegin(); it != files.constEnd(); ++progress, ++it) {
       addWordsFromFile (map, *it, encoding, codec);
 
       if (steps != 0 && progress*100/steps > percent) {
@@ -248,20 +252,20 @@ WordMap mergeFiles  (QMap<QString,int> files, KProgressDialog *pdlg) {
 
    QMap<QString,float> map;
    QMap<QString,int>::ConstIterator it;
-   for (progress = 1, it = files.begin(); it != files.end(); ++progress, ++it) {
+   for (progress = 1, it = files.constBegin(); it != files.constEnd(); ++progress, ++it) {
       WordMap fileMap;
       addWordsFromFile (fileMap, it.key(), QTextStream::UnicodeUTF8, 0);
 
       long long weight = 0;
       WordMap::ConstIterator iter;
-      for (iter = fileMap.begin(); iter != fileMap.end(); ++iter)
+      for (iter = fileMap.constBegin(); iter != fileMap.constEnd(); ++iter)
          weight += iter.value();
       float factor = 1.0 * it.value() / weight;
       totalWeight += it.value();
       if (weight > maxWeight)
          maxWeight = weight;
 
-      for (iter = fileMap.begin(); iter != fileMap.end(); ++iter)
+      for (iter = fileMap.constBegin(); iter != fileMap.constEnd(); ++iter)
          if (map.contains(iter.key()))
             map[iter.key()] += iter.value() * factor;
          else
@@ -282,7 +286,7 @@ WordMap mergeFiles  (QMap<QString,int> files, KProgressDialog *pdlg) {
 
    WordMap resultMap;
    QMap<QString,float>::ConstIterator iter;
-   for (iter = map.begin(); iter != map.end(); ++iter)
+   for (iter = map.constBegin(); iter != map.constEnd(); ++iter)
       resultMap[iter.key()] = (int)(factor * iter.value() + 0.5);
 
    return resultMap;
@@ -293,12 +297,12 @@ WordMap parseKDEDoc (QString language, KProgressDialog *pdlg) {
    pdlg->show();
    qApp->processEvents (QEventLoop::AllEvents, 20);
 
-   QStringList files = KGlobal::dirs()->findAllResources ("html", language + "/*.docbook",
+   QStringList files = KGlobal::dirs()->findAllResources ("html", language + QLatin1String( "/*.docbook" ),
                                                           KStandardDirs::Recursive |
                                                           KStandardDirs::NoDuplicates);
    if ((files.count() == 0) && (language.length() == 5)) {
       language = language.left(2);
-      files = KGlobal::dirs()->findAllResources ("html", language + "/*.docbook",
+      files = KGlobal::dirs()->findAllResources ("html", language + QLatin1String( "/*.docbook" ),
                                                  KStandardDirs::Recursive |
                                                  KStandardDirs::NoDuplicates);
    }
@@ -328,13 +332,13 @@ WordMap parseDir (QString directory, QTextStream::Encoding encoding, QTextCodec
    int dirNdx = 0;
    while (dirNdx < directories.count()) {
       QDir dir(directories.at(dirNdx));
-      const QFileInfoList entries = dir.entryInfoList ("*", QDir::Dirs | QDir::Files | QDir::NoSymLinks | QDir::Readable);
+      const QFileInfoList entries = dir.entryInfoList (QLatin1String( "*" ), QDir::Dirs | QDir::Files | QDir::NoSymLinks | QDir::Readable);
 
        for (int i = 0; i < entries.size(); ++i) {
             QFileInfo fileInfo = entries.at(i);
 
             QString name = fileInfo.fileName();
-            if (name != "." && name != "..") {
+            if (name != QLatin1String( "." ) && name != QLatin1String( ".." )) {
                if (fileInfo.isDir())
                   directories += fileInfo.filePath ();
                else
@@ -372,27 +376,27 @@ void loadAffFile(const QString &filename, AffMap &prefixes, AffMap &suffixes) {
       QTextStream stream(&afile);
       while (!stream.atEnd()) {
          QString s = stream.readLine();
-         QStringList fields = s.split( QRegExp("\\s"));
+         QStringList fields = s.split( QRegExp(QLatin1String( "\\s" )));
 
          if (fields.count() == 4) {
-            cross = (fields[2] == "Y");
+            cross = (fields[2] == QLatin1String( "Y" ));
          }
          else {
             if (fields.count() >= 5) {
                AffEntry e;
                e.cross     = cross;
-               if (fields[2] == "0")
+               if (fields[2] == QLatin1String( "0" ))
                   e.charsToRemove = 0;
                else
                   e.charsToRemove = fields[2].length();
                e.add       = fields[3];
 
-               if (fields[4] != ".") {
+               if (fields[4] != QLatin1String( "." )) {
                   QString condition = fields[4];
                   for (int idx = 0; idx < condition.length(); ++idx) {
-                     if (condition[idx] == '[') {
+                     if (condition[idx] == QLatin1Char( '[' )) {
                         QString code;
-                        for (++idx; (idx < condition.length()) && condition[idx] != ']'; ++idx)
+                        for (++idx; (idx < condition.length()) && condition[idx] != QLatin1Char( ']' ); ++idx)
                            code += condition[idx];
                         e.condition << code;
                      }
@@ -401,14 +405,14 @@ void loadAffFile(const QString &filename, AffMap &prefixes, AffMap &suffixes) {
                   }
                }
 
-               if (s.startsWith("PFX")) {
+               if (s.startsWith(QLatin1String("PFX"))) {
                   AffList list;
                   if (prefixes.contains (fields[1][0]))
                      list = prefixes[fields[1][0]];
                   list << e;
                   prefixes[fields[1][0]] = list;
                }
-               else if (s.startsWith("SFX")) {
+               else if (s.startsWith(QLatin1String("SFX"))) {
                   AffList list;
                   if (suffixes.contains (fields[1][0]))
                      list = suffixes[fields[1][0]];
@@ -437,11 +441,11 @@ inline bool checkCondition (const QString &word, const QStringList &condition) {
 
    QStringList::ConstIterator it;
    int idx;
-   for (it = condition.begin(), idx = word.length()-condition.count();
-        it != condition.end();
+   for (it = condition.constBegin(), idx = word.length()-condition.count();
+        it != condition.constEnd();
         ++it, ++idx)
    {
-      if ((*it).contains(word[idx]) == ((*it)[0] == '^'))
+      if ((*it).contains(word[idx]) == ((*it)[0] == QLatin1Char( '^' )))
          return false;
    }
    return true;
@@ -458,7 +462,7 @@ inline void checkWord(const QString &word, const QString &modifiers, bool cross,
          AffList sList = suffixes[modifiers[i]];
 
          AffList::ConstIterator sIt;
-         for (sIt = sList.begin(); sIt != sList.end(); ++sIt) {
+         for (sIt = sList.constBegin(); sIt != sList.constEnd(); ++sIt) {
             if (((*sIt).cross || !cross)
              && (checkCondition(word, (*sIt).condition)))
             {
@@ -486,7 +490,7 @@ void checkWord (const QString &word, const QString &modifiers, const WordMap &ma
          AffList pList = prefixes[modifiers[i]];
 
          AffList::ConstIterator pIt;
-         for (pIt = pList.begin(); pIt != pList.end(); ++pIt) {
+         for (pIt = pList.constBegin(); pIt != pList.constEnd(); ++pIt) {
             QString pWord = (*pIt).add + word;
             if (map.contains(pWord))
                checkedMap[pWord] = map[pWord];
@@ -499,11 +503,11 @@ void checkWord (const QString &word, const QString &modifiers, const WordMap &ma
 
 WordMap spellCheck  (WordMap map, QString dictionary, KProgressDialog *pdlg) {
 
-   if (dictionary.endsWith(".dic")) {
+   if (dictionary.endsWith(QLatin1String(".dic"))) {
       AffMap prefixes;
       AffMap suffixes;
       WordMap checkedMap;
-      loadAffFile (dictionary.left(dictionary.length()-4) + ".aff", prefixes, suffixes);
+      loadAffFile (dictionary.left(dictionary.length()-4) + QLatin1String( ".aff" ), prefixes, suffixes);
 
       pdlg->progressBar()->reset();
       pdlg->setAllowCancel (false);
@@ -529,9 +533,9 @@ WordMap spellCheck  (WordMap map, QString dictionary, KProgressDialog *pdlg) {
 
          while (!stream.atEnd()) {
             QString s = stream.readLine();
-            if (s.contains("/")) {
-               QString word = s.left(s.indexOf("/")).toLower();
-               QString modifiers = s.right(s.length() - s.indexOf("/"));
+            if (s.contains(QLatin1Char( '/' ))) {
+               QString word = s.left(s.indexOf(QLatin1Char( '/' ))).toLower();
+               QString modifiers = s.right(s.length() - s.indexOf(QLatin1Char(  '/' )));
 
                checkWord(word, modifiers, map, checkedMap, prefixes, suffixes);
             }
